@@ -3,16 +3,18 @@ Main interface for qldb service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.qldb import (
+    from mypy_boto3_qldb import (
         Client,
         QLDBClient,
-        )
+    )
 
     session = boto3.Session()
 
     client: QLDBClient = boto3.client("qldb")
     session_client: QLDBClient = session.client("qldb")
+    ```
 """
 from mypy_boto3_qldb.client import QLDBClient as Client, QLDBClient
 
