@@ -3,13 +3,15 @@ Main interface for qldb service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.qldb import QLDBClient
+    from mypy_boto3_qldb import QLDBClient
 
     session = boto3.Session()
 
     client: QLDBClient = boto3.client("qldb")
     session_client: QLDBClient = session.client("qldb")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
